# autogenerated module
from typing import ClassVar

from ..core import resource as res
from ..models import node_v1beta1 as m_node_v1beta1


class RuntimeClass(res.GlobalResource, m_node_v1beta1.RuntimeClass):
    """* **Extends**: ``models.node_v1beta1.RuntimeClass``
       * **Type**: Global Resource
       * **Accepted client methods**: `delete`, `deletecollection`, `get`, `list`, `patch`, `create`, `replace`, `watch`
    """
    _api_info = res.ApiInfo(
        resource=res.ResourceDef('node.k8s.io', 'v1beta1', 'RuntimeClass'),
        plural='runtimeclasses',
        verbs=['delete', 'deletecollection', 'get', 'list', 'patch', 'post', 'put', 'watch'],
    )

